Welcome to ECS-ComposeX's documentation!
========================================

.. toctree::
    :maxdepth: 1
    :caption: ECS ComposeX
    :titlesonly:

    readme
    getstarted
    usage

.. toctree::
    :maxdepth: 2
    :caption: Requisites

    requisites

.. toctree::
    :maxdepth: 2
    :caption: Installation

    installation
    contributing

.. toctree::
    :maxdepth: 1
    :caption: The Extras

    extras

.. toctree::
    :maxdepth: 1
    :caption: Modules

    modules_docs
    modules_syntax

.. toctree::
    :maxdepth: 2
    :caption: Package Modules

    modules

.. toctree::
    :maxdepth: 2
    :caption: The story

    story

.. toctree::
    :maxdepth: 2
    :caption: Contributions

    authors
    credits

.. toctree::
    :maxdepth: 2
    :caption: Changelog

    changelog

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
